steve

package module
v0.0.0-...-9c24627 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 20, 2021 License: Apache-2.0 Imports: 2 Imported by: 0

README

steve

steve gets state updates from UIs and injects legacy events into the event system based on those states

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DataService

type DataService interface {
	EventConfigs(context.Context, string) ([]EventConfig, error)
}

type Event

type Event struct {
	Key      string
	Value    string
	DeviceID string
	Tags     []string

	// RoomID is passed through from the original event, but can be overridden in config
	RoomID string

	// GeneratingSystem is passed through from the original event
	GeneratingSystem string

	// Timestamp is passed through from the original event
	Timestamp time.Time
}

type EventConfig

type EventConfig struct {
	MatchStates []string
	Events      []Event
}

type EventPublisher

type EventPublisher interface {
	Publish(context.Context, Event) error
}

type StateUpdate

type StateUpdate struct {
	GeneratingSystem string
	Timestamp        time.Time
	Room             string
	States           []string
}

type StateUpdateStreamer

type StateUpdateStreamer interface {
	Next(context.Context) (StateUpdate, error)
	Close() error
}

Directories

Path Synopsis
cmd
steve command
internal

Jump to